@@ -371,13 +371,29 @@ class AwsBackend(AvhBackend):
         """
         self._init()
         self.instance_id = self.create_ec2_instance(
+            BlockDeviceMappings=[{
+                'DeviceName': '/dev/sda1',
+                'Ebs': {
+                    'DeleteOnTermination': True,
+                    'Iops': 3000,
+                    'VolumeType': 'gp3',
+                    'Throughput': 150,
+                    'Encrypted': False
+                }
+            }],
             ImageId=self.ami_id,
             InstanceType=self.instance_type,
             MaxCount=1,
             MinCount=1,
+            NetworkInterfaces=[{
+                'AssociatePublicIpAddress': True,
+                'DeleteOnTermination': True,
+                'Description':'AVH Network Instance',
+                'DeviceIndex': 0,
+                'Groups': [self.security_group_id],
+                'SubnetId': self.subnet_id
+            }],
             KeyName=self.key_name,
-            SecurityGroupIds=self.security_group_id.split(" "),
-            SubnetId=self.subnet_id,
             TagSpecifications=[{'ResourceType': 'instance', 'Tags': [
                 {'Key': 'Name', 'Value': self.instance_name},
                 {'Key': 'AVH_CLI', 'Value': 'true'}
